#define GTK_MOZ_EMBED_MAJOR_VERSION (1)
#define GTK_MOZ_EMBED_MINOR_VERSION (7)
#define GTK_MOZ_EMBED_MICRO_VERSION (13)
#define GTK_MOZ_EMBED_CHECK_VERSION(major,minor,micro) \
	(GTK_MOZ_EMBED_MAJOR_VERSION > (major) || \
	 (GTK_MOZ_EMBED_MAJOR_VERSION == (major) && GTK_MOZ_EMBED_MINOR_VERSION > (minor)) || \
	 (GTK_MOZ_EMBED_MAJOR_VERSION == (major) && GTK_MOZ_EMBED_MINOR_VERSION == (minor) && GTK_MOZ_EMBED_MICRO_VERSION >= (micro)))
